@@ -1,5 +1,5 @@
 <?php
-/* unsafe_image_rules -- Version 0.1
+/* unsafe_image_rules -- Version 0.2
  * By Robin Rainton <robin@rainton.com>
  * http://rainton.com/fun/freeware
  *
@@ -16,19 +16,22 @@
 
   if (isset($unsafe_image_rules_submit)) {
      if (!isset($theid)) $theid = 0;
-     $what = ereg_replace(",", " ", $what);
-     $what = str_replace("\\\\", "\\", $what);
-     $what = str_replace("\\\"", "\"", $what);
-     $what = str_replace("\"", "&quot;", $what);
+/*
+ * This is a bit bad, but if $how is regexp then prefix
+ * $where with "R". This makes stuff backwards compatable.
+ */
+     if ($how == 'regexp') $where = "R" . $where;
 
      setPref($data_dir, $username, "unsafe_image_rules".$theid, $where.",".$what);
-     $filters[$theid]["where"] = $where;
-     $filters[$theid]["what"] = $what;
   } elseif (isset($action) && $action == 'delete') {
      remove_trusted($theid);
   } elseif (isset($user_submit)) {
       setPref($data_dir, $username, 'unsafe_image_rules_all',
               isset($uir_all) ? "1" : "0");
+      setPref($data_dir, $username, 'unsafe_image_rules_addr',
+              isset($uir_addr) ? "1" : "0");
+      setPref($data_dir, $username, 'unsafe_image_rules_ids',
+              isset($uir_ids) ? "1" : "0");
       setPref($data_dir, $username, 'unsafe_image_rules_trusted',
               isset($uir_trusted) ? "1" : "0");
       echo "<br><center><b>"._("Saved Trusted Options")."</b></center>\n";
@@ -36,6 +39,8 @@
 
   $unsafe_image_rules_list = load_unsafe_image_rules();
   $unsafe_image_rules_all = getPref($data_dir, $username, 'unsafe_image_rules_all');
+  $unsafe_image_rules_addr = getPref($data_dir, $username, 'unsafe_image_rules_addr');
+  $unsafe_image_rules_ids = getPref($data_dir, $username, 'unsafe_image_rules_ids');
   $unsafe_image_rules_trusted = getPref($data_dir, $username, 'unsafe_image_rules_trusted');
 
   echo '<br>' .
@@ -50,25 +55,58 @@
 
 /*
  * Trust all images option.
+ * This might be disabled by admin
  */
 
-  echo '<tr><th align=right nowrap>' . _("Trust all sources:") . '</th>'.
-       '<td><input type=checkbox name="uir_all"';
-  if (isset($unsafe_image_rules_all) && $unsafe_image_rules_all) {
+  if (!(isset($unsafe_image_rules_disable_all) && $unsafe_image_rules_disable_all))
+  {
+    echo '<tr><th align=right nowrap valign=top>' . _("Trust all sources:") . '</th>'.
+         '<td valign=top><input type=checkbox name="uir_all"';
+    if (isset($unsafe_image_rules_all) && $unsafe_image_rules_all) {
+        echo ' CHECKED';
+    }
+    echo "></td><td><small><B>WARNING!</B> This is not recommended by" .
+         " the Squirrelmail Development Team.<BR>" . 
+         "Read this <a href=\"http://www.squirrelmail.org/wiki/UnsafeImages\"> " .
+         "http://www.squirrelmail.org/wiki/UnsafeImages</a> for more details. " .
+         "There is a risk you may recieve more spam if you check this option.<BR>" .
+         "If checked unsafe images are always seen.<BR>" .
+         "If this option is checked, the state of other options is irrelevant." .
+          "</small></td><tr>" .
+          "</tr>\n";
+  }
+
+/*
+ * Trust addresses option.
+ */
+
+  echo '<tr><th align=right nowrap valign=top>' . _("Trust sources in address book:") . '</th>'.
+       '<td valign=top><input type=checkbox name="uir_addr"';         
+  if (isset($unsafe_image_rules_addr) && $unsafe_image_rules_addr) {
       echo ' CHECKED';
   }
-  echo "></td><td><small>If checked unsafe images are always seen. This is not recommended by" .
-       " the Squirrelmail Development Team.<BR>" . 
-       "If this option is checked, the state of 'Trust defined sources' is irrelevant." .
-        "</small></td><tr>" .
-        "</tr>\n";
+  echo "></td><td><small>If checked unsafe images are shown for messages from anyone in your address book." .
+       "</small></td></tr>\n";
+
+/*
+ * Trust IDs option.
+ */
+
+  echo '<tr><th align=right nowrap valign=top>' . _("Trust anything I send:") . '</th>'.
+       '<td valign=top><input type=checkbox name="uir_ids"';         
+  if (isset($unsafe_image_rules_ids) && $unsafe_image_rules_ids) {
+      echo ' CHECKED';
+  }
+  echo "></td><td><small>If checked unsafe images are shown for messages sent by any of your identities.<BR>" .
+       "You might not want to set this if you forward Spam to other people, and then go back and read from your 'Sent' folder." .
+       "</small></td></tr>\n";
 
 /*
  * Trust only some option.
  */
 
-  echo '<tr><th align=right nowrap>' . _("Trust defined sources:") . '</th>'.
-       '<td><input type=checkbox name="uir_trusted"';         
+  echo '<tr><th align=right nowrap valign=top>' . _("Trust defined sources:") . '</th>'.
+       '<td valign=top><input type=checkbox name="uir_trusted"';         
   if (isset($unsafe_image_rules_trusted) && $unsafe_image_rules_trusted) {
       echo ' CHECKED';
   }
@@ -118,13 +156,28 @@
     $sel = (($where_set && $unsafe_image_rules_list[$theid]['where'] == 'Subject')?'selected':'');
     echo "<option value=\"Subject\" $sel>" . _ ("Subject") . '</option>';
 
-    echo '</select>' .
-         _(" matches regexp: ") .
+    echo '</select><select name=how>';
+
+    $how_set = isset($unsafe_image_rules_list[$theid]['how']);
+
+    $sel = (!$how_set ||
+            ($how_set && $unsafe_image_rules_list[$theid]['how'] == 'contains')?'selected':'');
+    echo "<option value=\"contains\" $sel>" . _("Contains") . '</option>';
+
+    $sel = (($how_set && $unsafe_image_rules_list[$theid]['how'] == 'regexp')?'selected':'');
+    echo "<option value=\"regexp\" $sel>" . _("Reg.Exp.") . '</option>';
+
+    echo "</select>" .
          '<input type=text size=32 name=what value="';
     if (isset($unsafe_image_rules_list[$theid]['what'])) {
-      echo $unsafe_image_rules_list[$theid]["what"];
+      echo htmlentities($unsafe_image_rules_list[$theid]["what"]);
     }
     echo '"></td></tr><tr><td align=center>'.
+         "<table><tr><td valign=center align=right><b><small>NB:</small></b></td><td align=left>" .
+         "<small>" .
+         "When specifying a Reg.Exp you must include delimeters.<BR>" .
+         "The 'Contains' check will be done with case-insensitive match." .
+         "</small></td></tr></table>" .
          '<input type=submit name=unsafe_image_rules_submit value=' . _("Submit") . '>'.
          "<input type=hidden name=theid value=$theid>".
          '</td></tr></table>' .
@@ -141,8 +194,16 @@
             '</small></td><td><small>'.
             "[<a href=\"options.php?theid=$lp&action=delete\">" . _("Delete") . '</a>]' .
             "</small></td><td>-</td><td>";
-      printf( _("If <b>%s</b> matches <b>%s</b></b>"), _($unsafe_image_rules_list[$lp]['where']),
-                                                         $unsafe_image_rules_list[$lp]['what']);
+      printf( _("If <b>%s</b> %s <b>%s</b></b>"),
+              _($unsafe_image_rules_list[$lp]['where']),
+              ($unsafe_image_rules_list[$lp]['how'] == "regexp" ? ("Reg.Exp.")
+                                                                : ("Contains")),
+              htmlentities($unsafe_image_rules_list[$lp]['what']));
+      if ($unsafe_image_rules_list[$lp]['how'] == "regexp" &&
+          !is_good_regexp($unsafe_image_rules_list[$lp]['what']))
+      {
+        echo "<br><B>WARNING:</b> This doesn't loook like a valid Reg.Exp.";
+      }
       echo '</td></tr>';
 
   }
